<?php

class MGBS_plugin {



	/*--------------------------------------------*

	 * Constants

	 *--------------------------------------------*/

	

  const name = 'MGBS Standings';

	

  private $option_name                = "MGBS_OPTIONS";

  private $standings_data             = "";

  private $frequency_of_updates       = 43200;      //twice a day we will reach out and update standings

  private $default_division           = "nle";

  /**

	 * Constructor

	 */

  function __construct() {

    $this->plugin_location = substr(plugin_dir_url(__FILE__),0, strrpos(plugin_dir_url(__FILE__), "/",-2)) . "/";

    $opts = get_option($this->option_name);

    if (!$opts) {

      $opts =array();

      $opts['selected_division'] = "nle";

      $opts['last_updated']      = 0;

      update_option($this->option_name, $opts);

    }

    $last_updated = $opts['last_updated'];

    if (time()-(int)$last_updated >= $this->frequency_of_updates) {

      $this->update_standings();

    }

  	add_action( 'init', array( &$this, 'init_mgbs' ) );

  }

  

  function init_mgbs() {

      if ( is_admin() ) {

        add_action( 'admin_menu', array( &$this, 'add_admin_menu' ) );

        wp_register_style( 'mgbs-admin-style', $this->plugin_location . "css/mgbs-admin.css", false, '1.0.0' );

        wp_enqueue_style( 'mgbs-admin-style' );

        wp_register_script( 'mgbs-admin-script', $this->plugin_location . "js/mgbs-admin.js", false, '1.0.0' );

        wp_enqueue_script( 'mgbs-admin-script' );

        

        }

      wp_register_style( 'mgbs-site-style', $this->plugin_location . "css/mgbs.css", false, '1.0.0' );

      wp_enqueue_style( 'mgbs-site-style' );

      wp_enqueue_script('jquery');        

  }

        

  private function update_standings() {

    $standings                = new MGBS;

    $standings_array          = $standings->process();

    $opts = get_option($this->option_name);

    $opts['standings_array'] = $standings_array;

    $time = time();

    $opts['last_updated'] = time(); 

    update_option($this->option_name, $opts);

    return true;

  }

  



  

  public function add_admin_menu() {

    add_menu_page('MGBS Standings', 'MGBS Standings', 'administrator', "mgbs_admin_page", array( &$this, "admin_screen" ), $this->plugin_location."images/mgbs_icon.png");

  }

  

  private function handle_nonce($x,$y){

    if($_SERVER['REQUEST_METHOD'] == "POST" && 

        !wp_verify_nonce($x,$y) ) {

     print 'Sorry, there was a security issue with your update. If this persists, log out and log back in.';

     exit;

    }

  }

  

  

  public function admin_screen() {

    $too_soon_to_update = false;

    if (!current_user_can('manage_options'))  {

      wp_die( __('You do not have sufficient permissions to access this page.') );

    }

    if($_SERVER['REQUEST_METHOD'] == "GET" && $_GET['mgbs_refresh'] == 1)  {

      $this->update_standings();

      $action     = "mgbs-nonce";

      check_admin_referer($action);

      $message = wordpress_admin_helpers::update_msg("Manually re-fetched standings");    

    }

    $options = get_option($this->option_name);

    $last_updated = $options['last_updated'];

    $time_since_last_update = (time() - $last_updated);

    $minutes_to_update = 0;

    if ((time() - $last_updated)<(10*60)){

      $too_soon_to_update = true;

      $minutes_to_update = round(((60*10) - $time_since_last_update)/60,0);

    } 

    if (!is_numeric($last_updated)) {

      $last_updated = "NOT YET RAN";

    } else {

      $last_updated = date('l, F jS, Y h:i:s A', $last_updated + get_option( 'gmt_offset' ) * 3600);

    }

    

    

    ?>

    

    <div class="wrap">

    <div id="mgbs_admin"> 

    <?php echo $message; ?>

      <div class="icon32" id="icon-tools"><br></div>

      <h2><?php echo self::name;?> Options</h2>

      <div class="mgbs-admin-body">

      <?php       

            $raw_url    = "?page=" . $_GET['page'] . "&mgbs_refresh=1";

            $action     = "mgbs-nonce";

            $nonce_url  = wp_nonce_url($raw_url, $action); 

          ?>

      <?php if($too_soon_to_update){

              ?> <p><a class="button-primary too-soon" href="#">TOO SOON TO MANUALLY UPDATE, please wait approximately <?php echo $minutes_to_update;?> more minutes and try again.</a></p> <?php

            } else {

              ?>    <p><a class="button-primary" href="<?php echo $nonce_url;?>">Update Standings Manually</a></p><?php 

            } ?>

          <p class="note"><span>Note</span> Run "Update Standings Manually" if you are having trouble updating data. If you continue to have trouble, you can get in touch with me on Twitter, where my handle is <a href="http://twitter.com/matgargano" target="_BLANK">@matgargano</a>.</p>

          

          <h3>Preview:</h3>

          <div class="preview">

            <?php $output = new MGBS_plugin(); ?>

            <?php echo $output->output_standings(); ?>

          </div>

          <div class="clearboth"></div>

          <p class="lastupdated">Data last fetched: <span><?php echo $last_updated ?></span></p>

        </div>

      </div>

    </div>

    <?php

    return true;

  }

  function output_standings(){

    $opt = get_option($this->option_name);

    $standings["ALW"]  = $opt['standings_array']['data']['ALW'];

    $standings["ALE"]  = $opt['standings_array']['data']['ALE'];

    $standings["ALC"]  = $opt['standings_array']['data']['ALC'];

    $standings["NLW"]  = $opt['standings_array']['data']['NLW'];

    $standings["NLE"]  = $opt['standings_array']['data']['NLE'];

    $standings["NLC"]  = $opt['standings_array']['data']['NLC'];

    $widget_template            = file_get_contents($this->plugin_location . "templates/widget.php");

    $widget_table_template      = file_get_contents($this->plugin_location . "templates/widget_table.php");

    $widget_table_row_template  = file_get_contents($this->plugin_location . "templates/widget_table_row.php");

    foreach($standings as $key => $division){

      $output="";

      foreach($division as $team){

        $output .= sprintf($widget_table_row_template, MGBS_utilities::team_shortname($team['team_id']), $team['w'], $team['l'], $team['gb'], $team['gb']);

      }

      $table .= sprintf($widget_table_template, strtolower($key), $output);

    

    }

    

    return sprintf($widget_template, $table);

  }



  

}